@@ -6,10 +6,7 @@ use v5.14.2;
 
 use warnings;
 
-use subs qw();
-use vars qw($VERSION);
-
-$VERSION = '0.12';
+our $VERSION = '0.122';
 
 UNITCHECK {
 sub _running_under_tester {
@@ -33,11 +30,13 @@ __PACKAGE__->$method(@ARGV) if defined $method;
 
 =head1 NAME
 
-__PACKAGE__ - A demonstration of module ideas
+Modulino::Test - A demonstration of module ideas
 
 =head1 SYNOPSIS
 
-	use __PACKAGE__;
+This module isn't meant for use. It's an example of the modulino idea
+with an additional branch to recognize test situations then run as a
+test file.
 
 =head1 DESCRIPTION
 
@@ -135,7 +134,7 @@ sub _test_doc {
 
 This source is in Github:
 
-	http://github.com/briandfoy/modulino-demo/
+	https://github.com/briandfoy/modulino-demo/
 
 =head1 AUTHOR
 
@@ -143,9 +142,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2013-2014, brian d foy, All Rights Reserved.
+Copyright © 2013-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
-You may redistribute this under the same terms as Perl itself.
+You may redistribute this under the terms of the Artistic License 2.0.
 
 =cut
 
